==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-mediaplayer/i18n/l-mediap_ta.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta_IN">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../mainUI.ui" line="14"/>
        <location filename="../mainUI.cpp" line="285"/>
        <source>Media Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="50"/>
        <location filename="../mainUI.ui" line="261"/>
        <location filename="../mainUI.cpp" line="631"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="74"/>
        <source>(No Running Video)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="105"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="167"/>
        <source>up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="183"/>
        <source>down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="267"/>
        <source>Current Song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="303"/>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="327"/>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="337"/>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="368"/>
        <source>Love this song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="384"/>
        <source>Tired of this song (will not play for a month)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="397"/>
        <source>Ban this song (will never play again)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="417"/>
        <source>View details about song (launches web browser)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="448"/>
        <source>Current Station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="479"/>
        <source>Delete current station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="482"/>
        <source>rm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="492"/>
        <source>Create new station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="495"/>
        <source>add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="512"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="521"/>
        <source>Pandora Account Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="527"/>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="537"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="557"/>
        <source>&lt;a href=https://www.pandora.com/account/register&gt;Need an account?&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="573"/>
        <source>Audio Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="583"/>
        <source>Proxy URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="593"/>
        <source>Control Proxy URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="618"/>
        <source>Apply Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="656"/>
        <source>Audio Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="681"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="688"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="699"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="726"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="731"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="736"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="741"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="746"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="751"/>
        <source>VolUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="754"/>
        <source>Raise audio volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="759"/>
        <source>VolDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="762"/>
        <source>Lower audio volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="767"/>
        <source>Close Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="770"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="784"/>
        <source>Close to tray when active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="789"/>
        <source>From current artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="792"/>
        <source>Create station from current artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="797"/>
        <source>From current song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="800"/>
        <source>Create station from current song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="811"/>
        <source>Show song notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="816"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="819"/>
        <source>Search for a new station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="831"/>
        <location filename="../mainUI.cpp" line="276"/>
        <source>Pandora Radio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="834"/>
        <source>Stream from Pandora Radio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="842"/>
        <source>Local Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="845"/>
        <source>Play Local Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="105"/>
        <source>Please install the `pianobar` utility to enable this functionality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="109"/>
        <source>Stream music from the Pandora online radio service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="122"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="123"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="124"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="358"/>
        <source>Open Multimedia Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="406"/>
        <source>Now Playing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="471"/>
        <source>[PLAYBACK ERROR]
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="488"/>
        <source>Media Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="490"/>
        <source>Media Stalled...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="492"/>
        <source>Media Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="576"/>
        <source>Pandora: Create Station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="576"/>
        <source>Search Term</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="654"/>
        <source>Pandora Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="659"/>
        <source>Pandora Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PianoBarProcess</name>
    <message>
        <location filename="../PianoBarProcess.cpp" line="358"/>
        <source>Could not find any matches. Please try a different search term</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-mediaplayer/i18n/l-mediap_ta.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta_IN">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../mainUI.ui" line="14"/>
        <location filename="../mainUI.cpp" line="285"/>
        <source>Media Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="50"/>
        <location filename="../mainUI.ui" line="261"/>
        <location filename="../mainUI.cpp" line="631"/>
        <source>Now Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="74"/>
        <source>(No Running Video)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="105"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="167"/>
        <source>up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="183"/>
        <source>down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="267"/>
        <source>Current Song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="303"/>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="327"/>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="337"/>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="368"/>
        <source>Love this song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="384"/>
        <source>Tired of this song (will not play for a month)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="397"/>
        <source>Ban this song (will never play again)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="417"/>
        <source>View details about song (launches web browser)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="448"/>
        <source>Current Station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="479"/>
        <source>Delete current station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="482"/>
        <source>rm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="492"/>
        <source>Create new station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="495"/>
        <source>add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="512"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="521"/>
        <source>Pandora Account Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="527"/>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="537"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="557"/>
        <source>&lt;a href=https://www.pandora.com/account/register&gt;Need an account?&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="573"/>
        <source>Audio Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="583"/>
        <source>Proxy URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="593"/>
        <source>Control Proxy URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="618"/>
        <source>Apply Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="656"/>
        <source>Audio Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="681"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="688"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="723"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="728"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="733"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="738"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="743"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="748"/>
        <source>VolUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="751"/>
        <source>Raise audio volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="756"/>
        <source>VolDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="759"/>
        <source>Lower audio volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="764"/>
        <source>Close Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="767"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="781"/>
        <source>Close to tray when active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="786"/>
        <source>From current artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="789"/>
        <source>Create station from current artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="794"/>
        <source>From current song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="797"/>
        <source>Create station from current song</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="808"/>
        <source>Show song notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="813"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="816"/>
        <source>Search for a new station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="828"/>
        <location filename="../mainUI.cpp" line="276"/>
        <source>Pandora Radio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="831"/>
        <source>Stream from Pandora Radio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="839"/>
        <source>Local Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.ui" line="842"/>
        <source>Play Local Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="105"/>
        <source>Please install the `pianobar` utility to enable this functionality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="109"/>
        <source>Stream music from the Pandora online radio service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="122"/>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="123"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="124"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="358"/>
        <source>Open Multimedia Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="406"/>
        <source>Now Playing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="471"/>
        <source>[PLAYBACK ERROR]
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="488"/>
        <source>Media Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="490"/>
        <source>Media Stalled...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="492"/>
        <source>Media Buffering...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="576"/>
        <source>Pandora: Create Station</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="576"/>
        <source>Search Term</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="654"/>
        <source>Pandora Question</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainUI.cpp" line="659"/>
        <source>Pandora Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PianoBarProcess</name>
    <message>
        <location filename="../PianoBarProcess.cpp" line="358"/>
        <source>Could not find any matches. Please try a different search term</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
